==> fast_rx_shared_preferences-0.1.0.tar.gz: test/fast_rx_shared_preferences_test.dart <==
import 'dart:async';

import 'package:fast_rx_persistence/fast_rx_persistence.dart';
import 'package:fast_rx_shared_preferences/src/fast_rx_shared_preferences_base.dart';
import 'package:flutter/foundation.dart';
import 'package:shared_preferences/shared_preferences.dart';
import 'package:test/test.dart';
import 'package:fast_rx/fast_rx.dart';

void main() async {
  SharedPreferences.setMockInitialValues({});
  await FastRxSharedPreferences.init();
  final prefs = await SharedPreferences.getInstance();

  setUp(() {
    prefs.clear();
  });

  test('Integer preference', () async {
    unawaited(prefs.setInt('key', 1));

    final pref = 0.rx..persist('key');
    expect(pref.value, 1);

    pref.value = 2;
    // Wait for the stream to emit the update
    await Future.delayed(Duration.zero);
    expect(FastRxPersistence.store.get('key'), 2);
    expect(pref.value, 2);
  });

  test('Double preference', () async {
    unawaited(prefs.setDouble('key', 1.0));

    final pref = 0.0.rx..persist('key');
    expect(pref.value, 1.0);

    pref.value = 2.0;
    // Wait for the stream to emit the update
    await Future.delayed(Duration.zero);
    expect(FastRxPersistence.store.get('key'), 2.0);
    expect(pref.value, 2.0);
  });

  test('Boolean preference', () async {
    unawaited(prefs.setBool('key', true));

    final pref = false.rx..persist('key');
    expect(pref.value, true);

    pref.value = false;
    // Wait for the stream to emit the update
    await Future.delayed(Duration.zero);
    expect(FastRxPersistence.store.get('key'), false);
    expect(pref.value, false);
  });

  test('String preference', () async {
    unawaited(prefs.setString('key', 'value2'));

    final pref = 'value'.rx..persist('key');
    expect(pref.value, 'value2');

    pref.value = 'value3';
    // Wait for the stream to emit the update
    await Future.delayed(Duration.zero);
    expect(FastRxPersistence.store.get('key'), 'value3');
    expect(pref.value, 'value3');
  });

  test('String list preference', () async {
    unawaited(prefs.setStringList('key', ['']));

    final pref = <String>[].rx..persist('key');
    expect(listEquals(pref, ['']), isTrue);

    pref.replaceAll(['a', 'b', 'c']);
    // Wait for the stream to emit the update
    await Future.delayed(Duration.zero);
    // Ensure that the value is stored in Shared Preferences
    expect(
      listEquals(FastRxPersistence.store.get('key') as List, ['a', 'b', 'c']),
      isTrue,
    );
    expect(listEquals(pref, ['a', 'b', 'c']), isTrue);
  });

  test('Nullable preference removal', () async {
    final pref = RxValue<String?>('value')..persist('key');
    pref.value = 'newValue';
    // Wait for the stream to emit the update
    await Future.delayed(Duration.zero);
    expect(FastRxPersistence.store.get('key'), 'newValue');

    pref.value = null;
    // Wait for the stream to emit the update
    await Future.delayed(Duration.zero);
    // Ensure that the value is removed from Shared Preferences
    expect(FastRxPersistence.store.get('key'), null);
    expect(pref.value, null);
  });

  test('List of unsupported type', () {
    // Lists of types besides string are not supported
    expect(
      () => FastRxPersistence.store.set('key', [1, 2, 3]),
      throwsA(isA<UnsupportedError>()),
    );
  });

  test('Object of unsupported type', () {
    // Sets are not supported
    expect(
      () => FastRxPersistence.store.set('key', {}),
      throwsA(isA<UnsupportedError>()),
    );
  });
}

==> fast_rx_shared_preferences-0.1.2.tar.gz: test/fast_rx_shared_preferences_test.dart <==
import 'dart:async';

import 'package:fast_rx_persistence/fast_rx_persistence.dart';
import 'package:fast_rx_shared_preferences/fast_rx_shared_preferences.dart';
import 'package:flutter/foundation.dart';
import 'package:shared_preferences/shared_preferences.dart';
import 'package:test/test.dart';
import 'package:fast_rx/fast_rx.dart';

void main() async {
  SharedPreferences.setMockInitialValues({});
  await FastRxSharedPreferences.init();

  setUp(() {
    FastRxSharedPreferences.prefs.clear();
  });

  test('Integer preference', () async {
    unawaited(FastRxSharedPreferences.prefs.setInt('key', 1));

    final pref = 0.rx..persist('key');
    expect(pref.value, 1);

    pref.value = 2;
    // Wait for the stream to emit the update
    await Future.delayed(Duration.zero);
    expect(FastRxPersistence.store.get('key'), 2);
    expect(pref.value, 2);
  });

  test('Double preference', () async {
    unawaited(FastRxSharedPreferences.prefs.setDouble('key', 1.0));

    final pref = 0.0.rx..persist('key');
    expect(pref.value, 1.0);

    pref.value = 2.0;
    // Wait for the stream to emit the update
    await Future.delayed(Duration.zero);
    expect(FastRxPersistence.store.get('key'), 2.0);
    expect(pref.value, 2.0);
  });

  test('Boolean preference', () async {
    unawaited(FastRxSharedPreferences.prefs.setBool('key', true));

    final pref = false.rx..persist('key');
    expect(pref.value, true);

    pref.value = false;
    // Wait for the stream to emit the update
    await Future.delayed(Duration.zero);
    expect(FastRxPersistence.store.get('key'), false);
    expect(pref.value, false);
  });

  test('String preference', () async {
    unawaited(FastRxSharedPreferences.prefs.setString('key', 'value2'));

    final pref = 'value'.rx..persist('key');
    expect(pref.value, 'value2');

    pref.value = 'value3';
    // Wait for the stream to emit the update
    await Future.delayed(Duration.zero);
    expect(FastRxPersistence.store.get('key'), 'value3');
    expect(pref.value, 'value3');
  });

  test('String list preference', () async {
    unawaited(FastRxSharedPreferences.prefs.setStringList('key', ['']));

    final pref = <String>[].rx..persist('key');
    expect(listEquals(pref, ['']), isTrue);

    pref.replaceAll(['a', 'b', 'c']);
    // Wait for the stream to emit the update
    await Future.delayed(Duration.zero);
    // Ensure that the value is stored in Shared Preferences
    expect(
      listEquals(FastRxPersistence.store.get('key') as List, ['a', 'b', 'c']),
      isTrue,
    );
    expect(listEquals(pref, ['a', 'b', 'c']), isTrue);
  });

  test('Nullable preference removal', () async {
    final pref = RxValue<String?>('value')..persist('key');
    pref.value = 'newValue';
    // Wait for the stream to emit the update
    await Future.delayed(Duration.zero);
    expect(FastRxPersistence.store.get('key'), 'newValue');

    pref.value = null;
    // Wait for the stream to emit the update
    await Future.delayed(Duration.zero);
    // Ensure that the value is removed from Shared Preferences
    expect(FastRxPersistence.store.get('key'), null);
    expect(pref.value, null);
  });

  test('List of unsupported type', () {
    // Lists of types besides string are not supported
    expect(
      () => FastRxPersistence.store.set('key', [1, 2, 3]),
      throwsA(isA<UnsupportedError>()),
    );
  });

  test('Object of unsupported type', () {
    // Sets are not supported
    expect(
      () => FastRxPersistence.store.set('key', {}),
      throwsA(isA<UnsupportedError>()),
    );
  });
}
